@@ -145,18 +145,22 @@ pref("browser.cache.disk.smart_size.first_run", true);
 // Does the user want smart-sizing?
 pref("browser.cache.disk.smart_size.enabled", true);
 // Size explicitly set by the user. Used when smart_size.enabled == false
-//@line 69 "/builds/slave/m-beta-lnx64-xr/build/modules/libpref/src/init/all.js"
 pref("browser.cache.disk.capacity",         256000);
-//@line 73 "/builds/slave/m-beta-lnx64-xr/build/modules/libpref/src/init/all.js"
+// User-controllable max-size for entries in disk-cache. Regardless of this
+// setting, no entries bigger than 1/8 of disk-cache will be cached
+pref("browser.cache.disk.max_entry_size",    5120);
 pref("browser.cache.memory.enable",         true);
-//pref("browser.cache.memory.capacity",     -1);
 // -1 = determine dynamically, 0 = none, n = memory capacity in kilobytes
+//pref("browser.cache.memory.capacity",     -1);
+// User-controllable max-size for entries in mem-cache. Regardless of this
+// setting, no entries bigger than 90% of the mem-cache will be cached
+pref("browser.cache.memory.max_entry_size",  5120);
 pref("browser.cache.disk_cache_ssl",        true);
 // 0 = once-per-session, 1 = each-time, 2 = never, 3 = when-appropriate/automatically
 pref("browser.cache.check_doc_frequency",   3);
 
 pref("browser.cache.offline.enable",           true);
-//@line 82 "/builds/slave/m-beta-lnx64-xr/build/modules/libpref/src/init/all.js"
+
 // offline cache capacity in kilobytes
 pref("browser.cache.offline.capacity",         512000);
 
@@ -167,13 +171,15 @@ pref("offline-apps.quota.max",        204800);
 // the user should be warned if offline app disk usage exceeds this amount
 // (in kilobytes)
 pref("offline-apps.quota.warn",        51200);
-//@line 98 "/builds/slave/m-beta-lnx64-xr/build/modules/libpref/src/init/all.js"
 
 // Whether or not indexedDB is enabled.
 pref("dom.indexedDB.enabled", true);
 // Space to allow indexedDB databases before prompting (in MB).
 pref("dom.indexedDB.warningQuota", 50);
 
+// Whether window.performance is enabled
+pref("dom.enable_performance", true);
+
 // Fastback caching - if this pref is negative, then we calculate the number
 // of content viewers to cache based on the amount of available memory.
 pref("browser.sessionhistory.max_total_viewers", -1);
@@ -181,7 +187,6 @@ pref("browser.sessionhistory.max_total_viewers", -1);
 pref("browser.sessionhistory.optimize_eviction", true);
 
 pref("ui.use_native_colors", true);
-pref("ui.use_native_popup_windows", false);
 pref("ui.click_hold_context_menus", false);
 pref("browser.display.use_document_fonts",  1);  // 0 = never, 1 = quick, 2 = always
 pref("browser.display.use_document_colors", true);
@@ -245,13 +250,13 @@ pref("media.cache_size", 512000);
 // Master HTML5 media volume scale.
 pref("media.volume_scale", "1.0");
 
-//@line 179 "/builds/slave/m-beta-lnx64-xr/build/modules/libpref/src/init/all.js"
+//@line 177 "/builds/slave/m-beta-lnx64-xr/build/modules/libpref/src/init/all.js"
 pref("media.ogg.enabled", true);
-//@line 182 "/builds/slave/m-beta-lnx64-xr/build/modules/libpref/src/init/all.js"
+//@line 180 "/builds/slave/m-beta-lnx64-xr/build/modules/libpref/src/init/all.js"
 pref("media.wave.enabled", true);
-//@line 185 "/builds/slave/m-beta-lnx64-xr/build/modules/libpref/src/init/all.js"
+//@line 183 "/builds/slave/m-beta-lnx64-xr/build/modules/libpref/src/init/all.js"
 pref("media.webm.enabled", true);
-//@line 187 "/builds/slave/m-beta-lnx64-xr/build/modules/libpref/src/init/all.js"
+//@line 185 "/builds/slave/m-beta-lnx64-xr/build/modules/libpref/src/init/all.js"
 
 // Whether to autostart a media element with an |autoplay| attribute
 pref("media.autoplay.enabled", true);
@@ -267,10 +272,12 @@ pref("gfx.downloadable_fonts.fallback_delay", 3000);
 pref("gfx.downloadable_fonts.sanitize", true);
 
 // see gfx/thebes/gfxUnicodeProperties.h for definitions of script bits
-//@line 206 "/builds/slave/m-beta-lnx64-xr/build/modules/libpref/src/init/all.js"
+//@line 204 "/builds/slave/m-beta-lnx64-xr/build/modules/libpref/src/init/all.js"
 // use harfbuzz for default (0x01) + arabic (0x02)
 pref("gfx.font_rendering.harfbuzz.scripts", 3);
-//@line 209 "/builds/slave/m-beta-lnx64-xr/build/modules/libpref/src/init/all.js"
+//@line 207 "/builds/slave/m-beta-lnx64-xr/build/modules/libpref/src/init/all.js"
+
+//@line 212 "/builds/slave/m-beta-lnx64-xr/build/modules/libpref/src/init/all.js"
 
 //@line 216 "/builds/slave/m-beta-lnx64-xr/build/modules/libpref/src/init/all.js"
 
@@ -334,8 +341,11 @@ pref("toolkit.scrollbox.clickToScroll.scrollDelay", 150);
 
 // Telemetry
 pref("toolkit.telemetry.enabled", false);
-// Telemetry test server to be used until the official one is public
-pref("toolkit.telemetry.server", "http://telemetry.allizom.org");
+pref("toolkit.telemetry.server", "https://data.mozilla.com");
+// Telemetry server owner. Please change if you set toolkit.telemetry.server to a different server
+pref("toolkit.telemetry.server_owner", "Mozilla");
+// Information page about telemetry (temporary ; will be about:telemetry in the end)
+pref("toolkit.telemetry.infoURL", "http://www.mozilla.com/legal/privacy/firefox.html#telemetry");
 
 // view source
 pref("view_source.syntax_highlight", true);
@@ -646,9 +656,9 @@ pref("dom.min_timeout_value", 4);
 pref("dom.min_background_timeout_value", 1000);
 
 // Parsing perf prefs. For now just mimic what the old code did.
-//@line 593 "/builds/slave/m-beta-lnx64-xr/build/modules/libpref/src/init/all.js"
+//@line 596 "/builds/slave/m-beta-lnx64-xr/build/modules/libpref/src/init/all.js"
 pref("content.sink.pending_event_mode", 0);
-//@line 595 "/builds/slave/m-beta-lnx64-xr/build/modules/libpref/src/init/all.js"
+//@line 598 "/builds/slave/m-beta-lnx64-xr/build/modules/libpref/src/init/all.js"
 
 // Disable popups from plugins by default
 //   0 = openAllowed
@@ -663,7 +673,7 @@ pref("dom.event.contextmenu.enabled",       true);
 
 pref("javascript.enabled",                  true);
 pref("javascript.options.strict",           false);
-//@line 612 "/builds/slave/m-beta-lnx64-xr/build/modules/libpref/src/init/all.js"
+//@line 615 "/builds/slave/m-beta-lnx64-xr/build/modules/libpref/src/init/all.js"
 pref("javascript.options.relimit",          true);
 pref("javascript.options.tracejit.content",  true);
 pref("javascript.options.tracejit.chrome",   true);
@@ -678,7 +688,6 @@ pref("javascript.options.methodjit_always", false);
 // Comment 32 and Bug 613551.
 pref("javascript.options.mem.high_water_mark", 128);
 pref("javascript.options.mem.max", -1);
-pref("javascript.options.mem.gc_frequency",   300);
 pref("javascript.options.mem.gc_per_compartment", true);
 pref("javascript.options.mem.log", false);
 
@@ -709,7 +718,7 @@ pref("network.protocol-handler.external.data", false);
 pref("network.protocol-handler.external.ms-help", false);
 pref("network.protocol-handler.external.shell", false);
 pref("network.protocol-handler.external.vnd.ms.radio", false);
-//@line 660 "/builds/slave/m-beta-lnx64-xr/build/modules/libpref/src/init/all.js"
+//@line 662 "/builds/slave/m-beta-lnx64-xr/build/modules/libpref/src/init/all.js"
 pref("network.protocol-handler.external.disk", false);
 pref("network.protocol-handler.external.disks", false);
 pref("network.protocol-handler.external.afp", false);
@@ -824,6 +833,10 @@ pref("network.http.qos", 0);
 // connection.
 pref("network.http.connection-retry-timeout", 250);
 
+// Disable IPv6 for backup connections to workaround problems about broken
+// IPv6 connectivity.
+pref("network.http.fast-fallback-to-IPv4", false);
+
 // default values for FTP
 // in a DSCP environment this should be 40 (0x28, or AF11), per RFC-4594,
 // Section 4.8 "High-Throughput Data Service Class", and 80 (0x50, or AF22)
@@ -860,7 +873,12 @@ pref("network.websocket.timeout.ping.response", 10);
 
 // Defines whether or not to try and negotiate the stream-deflate compression
 // extension with the websocket server
-pref("network.websocket.extensions.stream-deflate", false);
+pref("network.websocket.extensions.stream-deflate", true);
+
+// the maximum number of concurrent websocket sessions. By specification there
+// is never more than one handshake oustanding to an individual host at
+// one time.
+pref("network.websocket.max-connections", 200);
 
 // </ws>
 
@@ -1048,7 +1066,7 @@ pref("network.negotiate-auth.gsslib", "");
 // Specify if the gss lib comes standard with the OS
 pref("network.negotiate-auth.using-native-gsslib", true);
 
-//@line 1004 "/builds/slave/m-beta-lnx64-xr/build/modules/libpref/src/init/all.js"
+//@line 1015 "/builds/slave/m-beta-lnx64-xr/build/modules/libpref/src/init/all.js"
 
 // Controls which NTLM authentication implementation we default to. True forces
 // the use of our generic (internal) NTLM authentication implementation vs. any
@@ -1109,6 +1127,7 @@ pref("converter.html2txt.structs",          true); // Output structured phrases
 pref("converter.html2txt.header_strategy",  1); // 0 = no indention; 1 = indention, increased with header level; 2 = numbering and slight indention
 
 pref("intl.accept_languages",               "chrome://global/locale/intl.properties");
+pref("intl.accept_charsets",                "iso-8859-1,*,utf-8");
 pref("intl.menuitems.alwaysappendaccesskeys","chrome://global/locale/intl.properties");
 pref("intl.menuitems.insertseparatorbeforeaccesskeys","chrome://global/locale/intl.properties");
 pref("intl.charsetmenu.browser.static",     "chrome://global/locale/intl.properties");
@@ -1143,7 +1162,7 @@ pref("intl.hyphenation-alias.en", "en-us");
 // and for other subtags of en-*, if no specific patterns are available
 pref("intl.hyphenation-alias.en-*", "en-us");
 
-pref("font.mathfont-family", "STIXNonUnicode, STIXSizeOneSym, STIXSize1, STIXGeneral, Standard Symbols L, DejaVu Sans, Cambria Math");
+pref("font.mathfont-family", "STIXNonUnicode, STIXSizeOneSym, STIXSize1, STIXGeneral, Asana Math, Standard Symbols L, DejaVu Sans, Cambria Math");
 
 // Some CJK fonts have bad underline offset, their CJK character glyphs are overlapped (or adjoined)  to its underline.
 // These fonts are ignored the underline offset, instead of it, the underline is lowered to bottom of its em descent.
@@ -1432,25 +1451,25 @@ pref("editor.positioning.offset",            0);
 pref("dom.max_chrome_script_run_time", 20);
 pref("dom.max_script_run_time", 10);
 
-//@line 1388 "/builds/slave/m-beta-lnx64-xr/build/modules/libpref/src/init/all.js"
+//@line 1400 "/builds/slave/m-beta-lnx64-xr/build/modules/libpref/src/init/all.js"
 // How long a plugin is allowed to process a synchronous IPC message
 // before we consider it "hung".
 pref("dom.ipc.plugins.timeoutSecs", 45);
 // How long a plugin launch is allowed to take before
 // we consider it failed.
 pref("dom.ipc.plugins.processLaunchTimeoutSecs", 45);
-//@line 1399 "/builds/slave/m-beta-lnx64-xr/build/modules/libpref/src/init/all.js"
+//@line 1411 "/builds/slave/m-beta-lnx64-xr/build/modules/libpref/src/init/all.js"
 
 // Disable oopp for standard java. They run their own process isolation (which
 // conflicts with our implementation, at least on Windows).
 pref("dom.ipc.plugins.java.enabled", false);
 
-//@line 1407 "/builds/slave/m-beta-lnx64-xr/build/modules/libpref/src/init/all.js"
+//@line 1419 "/builds/slave/m-beta-lnx64-xr/build/modules/libpref/src/init/all.js"
 // Linux plugins using Xt instead of Xembed don't work out-of-process yet.
 pref("dom.ipc.plugins.enabled.libvlcplugin.so", false);
 pref("dom.ipc.plugins.enabled.nppdf.so", false);
 pref("dom.ipc.plugins.enabled.602plugin.so", false);
-//@line 1414 "/builds/slave/m-beta-lnx64-xr/build/modules/libpref/src/init/all.js"
+//@line 1426 "/builds/slave/m-beta-lnx64-xr/build/modules/libpref/src/init/all.js"
 
 pref("svg.smil.enabled", true);
 
@@ -1487,15 +1506,15 @@ pref("font.minimum-size.x-western", 0);
 pref("font.minimum-size.x-unicode", 0);
 pref("font.minimum-size.x-user-def", 0);
 
-//@line 1910 "/builds/slave/m-beta-lnx64-xr/build/modules/libpref/src/init/all.js"
+//@line 1928 "/builds/slave/m-beta-lnx64-xr/build/modules/libpref/src/init/all.js"
 
-//@line 2343 "/builds/slave/m-beta-lnx64-xr/build/modules/libpref/src/init/all.js"
+//@line 2361 "/builds/slave/m-beta-lnx64-xr/build/modules/libpref/src/init/all.js"
 
-//@line 2543 "/builds/slave/m-beta-lnx64-xr/build/modules/libpref/src/init/all.js"
+//@line 2561 "/builds/slave/m-beta-lnx64-xr/build/modules/libpref/src/init/all.js"
 
-//@line 2812 "/builds/slave/m-beta-lnx64-xr/build/modules/libpref/src/init/all.js"
+//@line 2830 "/builds/slave/m-beta-lnx64-xr/build/modules/libpref/src/init/all.js"
 
-//@line 2816 "/builds/slave/m-beta-lnx64-xr/build/modules/libpref/src/init/all.js"
+//@line 2834 "/builds/slave/m-beta-lnx64-xr/build/modules/libpref/src/init/all.js"
 // Handled differently under Mac/Windows
 pref("network.protocol-handler.warn-external.file", false);
 pref("browser.drag_out_of_frame_style", 1);
@@ -1763,11 +1782,11 @@ pref("ui.panel.default_level_parent", true);
 
 pref("mousewheel.system_scroll_override_on_root_content.enabled", false);
 
-//@line 3087 "/builds/slave/m-beta-lnx64-xr/build/modules/libpref/src/init/all.js"
+//@line 3105 "/builds/slave/m-beta-lnx64-xr/build/modules/libpref/src/init/all.js"
 
-//@line 3107 "/builds/slave/m-beta-lnx64-xr/build/modules/libpref/src/init/all.js"
+//@line 3125 "/builds/slave/m-beta-lnx64-xr/build/modules/libpref/src/init/all.js"
 
-//@line 3115 "/builds/slave/m-beta-lnx64-xr/build/modules/libpref/src/init/all.js"
+//@line 3133 "/builds/slave/m-beta-lnx64-xr/build/modules/libpref/src/init/all.js"
 
 // Login Manager prefs
 pref("signon.rememberSignons",              true);
@@ -1821,7 +1840,11 @@ pref("image.mem.decodeondraw", false);
 // Minimum timeout for image discarding (in milliseconds). The actual time in
 // which an image must inactive for it to be discarded will vary between this
 // value and twice this value.
-pref("image.mem.min_discard_timeout_ms", 120000);
+//
+// This used to be 120 seconds, but having it that high causes our working
+// set to grow very large. Switching it back to 10 seconds will hopefully
+// be better.
+pref("image.mem.min_discard_timeout_ms", 10000);
 
 // Chunk size for calls to the image decoders
 pref("image.mem.decode_bytes_at_a_time", 200000);
@@ -1841,9 +1864,7 @@ pref("webgl.osmesalib", "");
 pref("webgl.verbose", false);
 pref("webgl.prefer-native-gl", false);
 
-//@line 3194 "/builds/slave/m-beta-lnx64-xr/build/modules/libpref/src/init/all.js"
-
-//@line 3199 "/builds/slave/m-beta-lnx64-xr/build/modules/libpref/src/init/all.js"
+//@line 3214 "/builds/slave/m-beta-lnx64-xr/build/modules/libpref/src/init/all.js"
 
 // Whether to disable acceleration for all widgets.
 pref("layers.acceleration.disabled", false);
@@ -1851,7 +1872,7 @@ pref("layers.acceleration.disabled", false);
 // Whether to force acceleration on, ignoring blacklists.
 pref("layers.acceleration.force-enabled", false);
 
-//@line 3218 "/builds/slave/m-beta-lnx64-xr/build/modules/libpref/src/init/all.js"
+//@line 3231 "/builds/slave/m-beta-lnx64-xr/build/modules/libpref/src/init/all.js"
 
 // Enable/Disable the geolocation API for content
 pref("geo.enabled", true);
