@@ -39,7 +39,8 @@ const PREFS_WHITELIST = [
   "places.",
   "print.",
   "privacy.",
-  "security."
+  "security.",
+  "webgl."
 ];
 
 // The blacklist, unlike the whitelist, is a list of regular expressions.
@@ -207,7 +208,7 @@ function populateGraphicsSection() {
     pushInfoRow(trGraphics, "driverVersion", gfxInfo.adapterDriverVersion);
     pushInfoRow(trGraphics, "driverDate", gfxInfo.adapterDriverDate);
 
-//@line 274 "/builds/slave/m-beta-lnx64-xr/build/toolkit/content/aboutSupport.js"
+//@line 275 "/builds/slave/m-beta-lnx64-xr/build/toolkit/content/aboutSupport.js"
 
     var webglrenderer;
     var webglenabled;
@@ -218,9 +219,9 @@ function populateGraphicsSection() {
       webglrenderer = false;
       webglenabled = false;
     }
-//@line 292 "/builds/slave/m-beta-lnx64-xr/build/toolkit/content/aboutSupport.js"
+//@line 293 "/builds/slave/m-beta-lnx64-xr/build/toolkit/content/aboutSupport.js"
     var webglfeature = gfxInfo.FEATURE_WEBGL_OPENGL;
-//@line 294 "/builds/slave/m-beta-lnx64-xr/build/toolkit/content/aboutSupport.js"
+//@line 295 "/builds/slave/m-beta-lnx64-xr/build/toolkit/content/aboutSupport.js"
     pushFeatureInfoRow(trGraphics, "webglRenderer", webglfeature, webglenabled, webglrenderer);
 
     appendChildren(graphics_tbody, trGraphics);
@@ -255,9 +256,9 @@ function populateGraphicsSection() {
   if (acceleratedWindows) {
     msg += " " + mgrType;
   } else {
-//@line 331 "/builds/slave/m-beta-lnx64-xr/build/toolkit/content/aboutSupport.js"
+//@line 332 "/builds/slave/m-beta-lnx64-xr/build/toolkit/content/aboutSupport.js"
     var feature = gfxInfo.FEATURE_OPENGL_LAYERS;
-//@line 333 "/builds/slave/m-beta-lnx64-xr/build/toolkit/content/aboutSupport.js"
+//@line 334 "/builds/slave/m-beta-lnx64-xr/build/toolkit/content/aboutSupport.js"
     var errMsg = errorMessageForFeature(feature);
     if (errMsg)
       msg += ". " + errMsg;
@@ -389,7 +390,7 @@ function createTextForElement(elem) {
   text = text.replace(/\n\n\n+/g, "\n\n");
 
   // Actual CR/LF pairs are needed for some Windows text editors.
-//@line 467 "/builds/slave/m-beta-lnx64-xr/build/toolkit/content/aboutSupport.js"
+//@line 468 "/builds/slave/m-beta-lnx64-xr/build/toolkit/content/aboutSupport.js"
 
   return text;
 }
